PinItemState class
A class that represents the state of a pin item.
Constructors
- PinItemState({required String value, required int index, required PinItemStateType type})
-
Creates a new instance of PinItemState.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The index of the individual pin item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PinItemStateType
-
The state of the individual pin item.
final
- value → String
-
The value of the individual pin item.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited